//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
import { isNonEmptyString, isObject, ttl, getWindow } from 'primeobjects-helper-util/build/cjs/core';
import { isNil, isInteger } from 'lodash';
export var getLocalStorage = function (key, defaultValue) {
    if (!isNonEmptyString(key))
        return null;
    var data = null;
    var storageData = getWindow().localStorage.getItem(key);
    if (isNil(storageData))
        return defaultValue;
    if (isNonEmptyString(storageData)) {
        try {
            data = JSON.parse(storageData);
            if (isObject(data) && isInteger(data.ttl)) //ttl in seconds
             {
                if (Date.now() > data.ttl * 1000) {
                    removeLocalStorage(key);
                    return !isNil(defaultValue) ? defaultValue : null;
                }
                else {
                    return data.data;
                }
            }
        }
        catch (_a) {
            data = storageData;
        }
    }
    else {
        data = storageData;
    }
    return !isNil(data) ? data : (!isNil(defaultValue) ? defaultValue : null);
};
export var setLocalStorage = function (key, data, expireMinutes) {
    if (!isNonEmptyString(key))
        return null;
    if (isNil(data))
        return getWindow().localStorage.removeItem(key);
    if (expireMinutes && isInteger(expireMinutes) && expireMinutes > 0) {
        var storageData = { data: data, ttl: ttl(expireMinutes) };
        getWindow().localStorage.setItem(key, JSON.stringify(storageData));
    }
    else {
        getWindow().localStorage.setItem(key, isObject(data) ? JSON.stringify(data) : data);
    }
};
export var removeLocalStorage = function (key) {
    localStorage.removeItem(key);
};
//# sourceMappingURL=local-storage.js.map